Learn R Programming

RStripe (version 0.1)

stripe_delete_plan: Delete a plan on Stripe.

Description

Delete a plan in your system. Only able to do this if you have no subscriptions on it.

Usage

stripe_delete_plan(api_key, plan_id)

Arguments

api_key
Your Stripe API Key
plan_id
The id for the plan you want to delete

Value

A data frame with nothing if successful.