stripe_create_invoice_item: Create an Invoice Item.
Description
Create a new invoice item with amount and attach it to a subscription or invoice.
If you leave invoice blank it will be added to the next upcoming invoice.
Usage
stripe_create_invoice_item(api_key, args)
Arguments
api_key
Your Stripe API Key
args
A list which must contain
- amount
- required In cents how much for item.
- currency
- required 3-letter ISO code for currency.
- description
- optional A string to attach to item for easy tracking.
- metadata
- optional key/value pairs that you can attach to an invoice item.
- invoice
- optional Add to this invoice or leave blank for next invoice.
- subscription
- optional Add to a specific subscriptions invoice.
Value
A data frame with the new invoice item if successful.