stripe_list_invoice_items: List all Invoice Item.
Description
List all the invoice items in your account. This can be limited by customer, date, etc.
Usage
stripe_list_invoice_items(api_key, args = NULL)
Arguments
api_key
Your Stripe API Key
args
A list which can contain:
- ending_before
- optional: An object id which will show objects before
- customer
- optional: The customer ID whose invoice items to return
- limit
- optional: A number 1 to 100 to limit the items. Default is 10
- starting_after
- optional: An object id which will show objects starting here
Value
A data frame with the the invoice items if successful.